Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4593)

Unified Diff: chrome/browser/chromeos/drive/file_system/move_operation.h

Issue 12038058: Revert 178494 (Closed) Base URL: svn://svn.chromium.org/chrome/branches/1364/src/
Patch Set: Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/chromeos/drive/file_system/move_operation.h
===================================================================
--- chrome/browser/chromeos/drive/file_system/move_operation.h (revision 178502)
+++ chrome/browser/chromeos/drive/file_system/move_operation.h (working copy)
@@ -86,34 +86,36 @@
const FileMoveCallback& callback,
google_apis::GDataErrorCode status);
// Removes a file or directory at |file_path| from the current directory.
// It moves the entry to a dangle, no-parent state on the server side.
//
// Can be called from UI thread. |callback| is run on the calling thread.
// |callback| must not be null.
- void RemoveEntryFromDirectory(const FileMoveCallback& callback,
- DriveFileError error,
- const FilePath& file_path);
+ void RemoveEntryFromNonRootDirectory(const FileMoveCallback& callback,
+ DriveFileError error,
+ const FilePath& file_path);
- // Part of RemoveEntryFromDirectory(). Called after
+ // Part of RemoveEntryFromNonRootDirectory(). Called after
// GetEntryInfoPairByPaths() is complete. |callback| must not be null.
- void RemoveEntryFromDirectoryAfterEntryInfoPair(
+ void RemoveEntryFromNonRootDirectoryAfterEntryInfoPair(
const FileMoveCallback& callback,
scoped_ptr<EntryInfoPairResult> result);
// Moves a file or directory at |file_path| to another directory at
// |dir_path|.
//
// Can be called from UI thread. |callback| is run on the calling thread.
// |callback| must not be null.
- void AddEntryToDirectory(const FilePath& directory_path,
- const FileOperationCallback& callback,
- DriveFileError error,
- const FilePath& file_path);
+ void MoveEntryFromRootDirectory(const FilePath& directory_path,
+ const FileOperationCallback& callback,
+ DriveFileError error,
+ const FilePath& file_path);
- // Part of AddEntryToDirectory(). Called after
+ // Part of MoveEntryFromRootDirectory(). Called after
// GetEntryInfoPairByPaths() is complete. |callback| must not be null.
- void AddEntryToDirectoryAfterGetEntryInfoPair(
+ void MoveEntryFromRootDirectoryAfterGetEntryInfoPair(
const FileOperationCallback& callback,
scoped_ptr<EntryInfoPairResult> result);
@@ -86,34 +86,36 @@
const FileMoveCallback& callback,
google_apis::GDataErrorCode status);
- // Removes a file or directory at |file_path| from the current directory.
- // It moves the entry to a dangle, no-parent state on the server side.
+ // Removes a file or directory at |file_path| from the current directory if
+ // it's not in the root directory. This essentially moves an entry to the
+ // root directory on the server side.
//
// Can be called from UI thread. |callback| is run on the calling thread.
@@ -86,34 +86,36 @@
const FileMoveCallback& callback,
scoped_ptr<EntryInfoPairResult> result);
- // Moves a file or directory at |file_path| to another directory at
- // |dir_path|.
+ // Moves a file or directory at |file_path| in the root directory to
+ // another directory at |dir_path|. This function does nothing if
+ // |dir_path| points to the root directory.
//
// Can be called from UI thread. |callback| is run on the calling thread.

Powered by Google App Engine
This is Rietveld 408576698